@@ -1,6 +1,6 @@
 #ICLUST  - a function to form homogeneous item composites
-# based upon Revelle, W. (1979). Hierarchical cluster analysis and the internal structure of tests. Multivariate Behavioral Research, 14, 57-74.
-#
+# originally based upon Revelle, W. (1979). Hierarchical cluster analysis and the internal structure of tests. Multivariate Behavioral Research, 14, 57-74.
+# but much changed over the year
 # psudo code
 #	find similarity matrix
 #		original is either covariance or correlation
@@ -11,18 +11,17 @@
 #update similarity matrix
 #repeat until finished
 #then report various summary statistics
-#example code
-#r.mat<- Harman74.cor$cov
-# print(ICLUST(r.mat),digits=2)
+
 
 #ICLUST is the main function and calls other routines
 "iclust" <- 
- function (r.mat,nclusters=0,alpha=3,beta=1,beta.size=4,alpha.size=3,correct=TRUE,correct.cluster=TRUE,reverse=TRUE,beta.min=.5,output=1,digits=2,labels=NULL,cut=0,n.iterations=0,title="iclust",plot=TRUE,weighted=TRUE,cor.gen =TRUE,SMC=TRUE ) {
-ICLUST(r.mat,nclusters,alpha,beta,beta.size,alpha.size,correct,correct.cluster,reverse,beta.min,output,digits,labels,cut,n.iterations,title,plot,weighted,cor.gen,SMC )}
+ function (r.mat,nclusters=0,alpha=3,beta=1,beta.size=4,alpha.size=3,correct=TRUE, 
+ correct.cluster=TRUE,reverse=TRUE,beta.min=.5,output=1,digits=2,labels=NULL,cut=0,n.iterations=0,title="iclust",plot=TRUE,weighted=TRUE,cor.gen =TRUE,SMC=TRUE,purify=TRUE ) {
+ICLUST(r.mat,nclusters,alpha,beta,beta.size,alpha.size,correct,correct.cluster,reverse,beta.min,output,digits,labels,cut,n.iterations,title,plot,weighted,cor.gen,SMC,purify)}
 
 
 "ICLUST" <- 
- function (r.mat,nclusters=0,alpha=3,beta=1,beta.size=4,alpha.size=3,correct=TRUE,correct.cluster=TRUE,reverse=TRUE,beta.min=.5,output=1,digits=2,labels=NULL,cut=0,n.iterations=0,title="ICLUST",plot=TRUE,weighted=TRUE,cor.gen =TRUE,SMC=TRUE ) {#should allow for raw data, correlation or covariances
+ function (r.mat,nclusters=0,alpha=3,beta=1,beta.size=4,alpha.size=3,correct=TRUE,correct.cluster=TRUE,reverse=TRUE,beta.min=.5,output=1,digits=2,labels=NULL,cut=0,n.iterations=0,title="ICLUST",plot=TRUE,weighted=TRUE,cor.gen =TRUE,SMC=TRUE,purify=TRUE ) {#should allow for raw data, correlation or covariances
 
  #ICLUST.options <- list(n.clus=1,alpha=3,beta=1,beta.size=4,alpha.size=3,correct=TRUE,correct.cluster=TRUE,reverse=TRUE,beta.min=.5,output=1,digits=2,cor.gen=TRUE) 
  cl <- match.call()
@@ -39,37 +38,42 @@ ICLUST(r.mat,nclusters,alpha,beta,beta.size,alpha.size,correct,correct.cluster,r
 	  stop() }
 	if(is.null(colnames(r.mat))) {colnames(r.mat) <- paste("V",1:nvar,sep="")} 
 	if(is.null(rownames(r.mat))) {rownames(r.mat) <- paste("V",1:nvar,sep="")} 
-	iclust.results <- ICLUST.cluster(r.mat,ICLUST.options) #this does all the work - the answers are in iclust.results
+	iclust.results <- ICLUST.cluster(r.mat,ICLUST.options) #ICLUST.cluster does all the work - the answers are in iclust.results
 	
-	loads <- cluster.loadings(iclust.results$clusters,r.mat,SMC=SMC) #summarize the results by using cluster.loadings
+	loads <- cluster.loadings(iclust.results$clusters,r.mat,SMC=SMC) #summarize the results by using cluster.loadings  -- these are the original values
 	
-	if(is.matrix(iclust.results$cluster) ) {
-		eigenvalue <- diag(t(loads$loading) %*% loads$loading)
+	if(is.matrix(iclust.results$clusters) ) {
+		eigenvalue <- diag(t(loads$pattern) %*% loads$loading)
 		sorted.cluster.keys.ord <- order(eigenvalue,decreasing=TRUE)
 		sorted.cluster.keys <- iclust.results$clusters[,sorted.cluster.keys.ord]
-	loads <- cluster.loadings(sorted.cluster.keys,r.mat,SMC=SMC) } else {sorted.cluster.keys <- iclust.results$clusters}
+	loads <- cluster.loadings(sorted.cluster.keys,r.mat,SMC=SMC)  #these are the original cluster loadings with clusters sorted by eigenvalues   
+	iclust.results$clusters <- sorted.cluster.keys
+	cluster.beta <- iclust.results$results[colnames(sorted.cluster.keys),"beta"]
+		names(cluster.beta) <- colnames(sorted.cluster.keys)} else {sorted.cluster.keys <- iclust.results$clusters} #these are fine
 	
-	fits <- cluster.fit(r.mat,as.matrix(loads$loadings),iclust.results$clusters)
-	sorted <- ICLUST.sort(ic.load=loads,labels=labels,cut=cut) #sort the loadings (again?  I think this might not be necessary anymore
+	fits <- cluster.fit(r.mat,as.matrix(loads$loadings),iclust.results$clusters)  #check this 
+	sorted <- ICLUST.sort(ic.load=loads,labels=labels,cut=cut) #sort the loadings (again?) This is done for sorted output if desired
 	
 	if(is.matrix(sorted.cluster.keys) ) {cluster.beta <- iclust.results$results[colnames(sorted.cluster.keys),"beta"]
-	names(cluster.beta) <- colnames(sorted.cluster.keys) } else {
-	number.of.clusters <- dim(iclust.results$results)[1]
-	cluster.beta <- iclust.results$results[number.of.clusters,"beta"]}
+		names(cluster.beta) <- colnames(sorted.cluster.keys) 
+		} else {
+			number.of.clusters <- dim(iclust.results$results)[1]
+			cluster.beta <- iclust.results$results[number.of.clusters,"beta"]}
 	
 	#now, iterate the cluster solution to clean it up (if desired)
 	
-		clusters <- as.matrix(iclust.results$clusters)     #just in case there is only one cluster
+		clusters <- as.matrix(iclust.results$clusters)     #just in case there is only one cluster  -- these are now sorted by eigen value
+		
 		if (dim(clusters)[2]==0 ) {warning('no items meet the specification time1')}
 		old.clusters <- clusters
 		old.fit <- fits$clusterfit
 		if (ICLUST.debug) {print(paste('clusters ',clusters))}
-		clusters <- factor2cluster(loads,cut=cut)
-		clusters <- as.matrix(clusters)   #in case only one cluster 
+		if(purify) {clusters <- factor2cluster(loads,cut=cut)    #this will assign items to the clusters with the highest loadings --  might be different from original solution
+			clusters <- as.matrix(clusters) }  #in case only one cluster 
 		if (dim(clusters)[2]==0 ) {warning('no items meet the specification stage 2',immediate.=TRUE)}
 		if (ICLUST.debug) {print(paste('clusters ',clusters))
 		 print(paste('loads ',loads))}
-		loads <- cluster.loadings(clusters,r.mat,SMC=SMC)
+		loads <- cluster.loadings(clusters,r.mat,SMC=SMC) 
 		
 		if (n.iterations > 0) {  #it is possible to iterate the solution to perhaps improve it 
 		for (steps in 1:n.iterations) {   #
@@ -87,16 +91,19 @@ ICLUST(r.mat,nclusters,alpha,beta,beta.size,alpha.size,correct,correct.cluster,r
 		old.fit <- fit$cluster.fit
 					}
 		}
-
+   
 	p.fit <- cluster.fit(r.mat,as.matrix(loads$loadings),clusters)
-	p.sorted <- ICLUST.sort(ic.load=loads,labels=labels,cut=cut,keys=TRUE)
+	p.sorted <- ICLUST.sort(ic.load=loads,labels=labels,cut=cut,keys=TRUE)   #at this point, the clusters have been cleaned up, but are not in a sorted order.  Sort them
 	
-	purified <- cluster.cor(p.sorted$clusters,r.mat,digits=digits,SMC=SMC)
+	purified <- cluster.cor(p.sorted$clusters,r.mat,SMC=SMC)
 	class(loads$loadings) <- "loading"
-	result <- list(title=title,clusters=iclust.results$clusters,corrected=loads$corrected,loadings=loads$loadings,pattern=loads$pattern,G6 = loads$G6,fit=fits,results=iclust.results$results,cor=loads$cor,Phi=loads$cor,alpha=loads$alpha,beta=cluster.beta,av.r = loads$av.r,size=loads$size,sorted=sorted,p.fit = p.fit,p.sorted = p.sorted,purified=purified,call=cl)
+	result <- list(title=title,clusters=iclust.results$clusters,corrected=loads$corrected,loadings=loads$loadings,pattern=loads$pattern,G6 = loads$G6,fit=fits,results=iclust.results$results,cor=loads$cor,Phi=loads$cor,alpha=loads$alpha,beta=cluster.beta,av.r = loads$av.r,size=loads$size,
+	sorted=sorted,
+	p.fit = p.fit,p.sorted = p.sorted,purified=purified,purify=purify,call=cl)
 	#if(plot && require(Rgraphviz)) {ICLUST.rgraph(result,labels=labels,title=title,digits=digits)}
 	if(plot) iclust.diagram(result,labels=labels,main=title,digits=digits)
 	class(result) <- c("psych","iclust")
+
 	return(result)
 }   
 
