@@ -1,5 +1,5 @@
 "iclust.diagram" <- 
-function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1, main="ICLUST diagram") {
+function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram") {
 
  
 
@@ -16,7 +16,7 @@ if(is.null(cex)) cex <- min(16/num.var,1)
 
 fixed <- fix.names(ic,var.labels)
 clusters <- fixed$ic$results
- max.len <- max(nchar((var.labels)))
+max.len <- max(nchar((var.labels)))
 
 length.labels <- max(max.len* .15 * cex,.25*cex)
 ##
@@ -34,28 +34,36 @@ if(nvar < 12) e.size <- e.size * .7   #this is a kludge to make small problems l
 if(is.null(min.size)) min.size <- .1 * nvar
 plot(0,type="n",xlim=limx,ylim=limy,frame.plot=FALSE,axes=FALSE,ylab="",xlab="",main=main)
 new.max.len <- max(strwidth(var.labels))
-if (new.max.len > max.len) {limx <- c(-new.max.len
-,nvar+2)
+if (new.max.len > max.len) {limx <- c(-new.max.len,nvar+2)
 plot(0,type="n",xlim=limx,ylim=limy,frame.plot=FALSE,axes=FALSE,ylab="",xlab="",main=main)}
 top <- num.var
 done <- 0
 if (nc==1) {head <- num
            size <- num.var
            y.loc <- clusters[head,"size2"]
-	       down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy)
+	       down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
 	       } else {
 #the multiple cluster case           
 for(clust in 1:nc) {
-    size <- ic$size[clust]
-	if (substr(names(ic$size[clust]),1,1)=="C") {
+   #size <- ic$size[clust]
+   size <-  sum(abs(ic$clusters[,clust]))
 	
-	head <- which(rownames(clusters)==names(ic$size[clust]))
+	if (substr(colnames(ic$clusters)[clust],1,1)=="C") {
 	
-	cluster <- clusters[head,]
-	 y.loc <- clusters[head,"size2"] + done
-    down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy) } 
+	#head <- which(rownames(clusters)==names(ic$size[clust]))
+	 head <- which(rownames(clusters)==colnames(ic$clusters)[clust])
+	
+		cluster <- clusters[head,]
+		 y.loc <- clusters[head,"size2"] + done
+    	down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
+      }  else {v.name <-names(which(ic$clusters[,clust] ==1))
+      dia.rect(0,done+.5,v.name,xlim=limx,ylim=limy,cex=cex)
+    
+       #done <- done + 1
+       }
 	done <- done + size 
 } 
+         
 }}
 
  fix.names <- function(ic,var.labels) {
@@ -81,14 +89,14 @@ for(clust in 1:nc) {
 
     
  "dia.cluster" <- 
- function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),small=FALSE, ...) {
+ function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),small=FALSE) {
    
 	if(!small) {
 	 text(x,y, rownames(cluster),pos=3,cex=cex)
 	 text(x,y, substitute(list(alpha) == list(a),list(a=round(cluster[1,"alpha"],digits))),cex=cex) 
 	text(x,y, substitute(list(beta) == list(b), list(b=round(cluster[1,"beta"],digits))),cex=cex,pos=1) } else { text(x,y, rownames(cluster),cex=cex) }
      vert <- cex*.3
-     xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size,...)
+     xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size)
      left <- c(x-xs,y)
      right <- c(x+xs,y)
      top <- c(x,y+xs)
@@ -101,8 +109,9 @@ for(clust in 1:nc) {
   #down is a recursive function that draws the complete cluster structure
   
    "down" <- 
-   function(clusters,head,x,y,old.head = NULL,old.loc=NULL,digits,cex,limx,limy,min.size=1,e.size=.6,...) {
-
+   function(clusters,head,x,y,sign.clust=1,old.head = NULL,old.loc=NULL,digits,cex,limx,limy,min.size=1,e.size=.6,color.lines=TRUE,colors=c("black","blue")) {
+   
+  
            shift <-2
            size <- clusters[head,"size"]
 		   cluster <- clusters[head,]
@@ -111,39 +120,44 @@ for(clust in 1:nc) {
 
            if(!is.null(old.loc)) { 
            						if(old.loc$top[2] < c.loc$top[2]) {labels <- round(clusters[c.loc$link,"r1"],digits) } else { labels <- round(clusters[c.loc$link,"r2"],digits)}
+        						sign.clust <-  sign(labels)
         						if(old.loc$left[1] < c.loc$right[1]) {
         											if(old.loc$left[2] < c.loc$right[2]) { 
-                                          				dia.arrow(old.loc,c.loc,labels=labels,cex=cex)} else {
-                                          dia.arrow(old.loc,c.loc,labels=labels,cex=cex)}} else {
-          					 dia.arrow(old.loc,c.loc,labels=labels,cex=cex)}}
+        											   
+        											    sign.clust <-   sign(labels) 
+                                          				dia.arrow(old.loc,c.loc,labels=labels,cex=cex,col=colors[((sign.clust < 0)+1)],lty=(sign.clust < 0)+1)} else {
+                                          dia.arrow(old.loc,c.loc,labels=labels,cex=cex,col=colors[((sign.clust <0)+1)],lty=((sign.clust)<0)+1)}} else {
+          					 dia.arrow(old.loc,c.loc,labels=labels,cex=cex,col=colors[((sign(labels)<0)+1)],lty=((sign(labels)<0)+1))}}
                 size1 <- clusters[head,"size1"]
                 size2 <- clusters[head,"size2"]
                                                                 
                if(size1==1) {
-                v.loc <-  dia.rect(0,y+.5,clusters[head,1],xlim=limx,ylim=limy,cex=cex,...)
-
-                dia.arrow(c.loc,v.loc$right,round(cluster["r1"],digits),cex=cex)
+                v.loc <-  dia.rect(0,y+.5,clusters[head,1],xlim=limx,ylim=limy,cex=cex)
+                 #sign.clust <- sign.clust *sign(cluster["r1"])
+                 sign.clust <-    sign(cluster["r1"]) 
+                dia.arrow(c.loc,v.loc$right,round(cluster["r1"],digits),cex=cex,col=colors[((sign.clust)<0) +1],lty=((sign.clust) <0)+ 1)
                   } else {
                     
                		head1 <- which(rownames(clusters)== clusters[head,1]) 
                		cluster <- clusters[head1,]   #get ready to go down the tree
 
                		y.shift <- clusters[head1,"size2"]
-              		down(clusters,head1,x,y+y.shift,old.head=head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,...) 
+              		down(clusters,head1,x,y+y.shift,sign.clust,old.head=head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors) 
               		} 
               		 
               		if(size2==1) {
 
-              			v.loc <- dia.rect(0,y-.5,clusters[head,2],xlim=limx,ylim=limy,cex=cex,...)
-
-              			dia.arrow(c.loc,v.loc$right,labels = round(clusters[head,"r2"],digits),cex=cex)
+              			v.loc <- dia.rect(0,y-.5,clusters[head,2],xlim=limx,ylim=limy,cex=cex)
+              			sign.clust <-  sign(clusters[head,"r2"])
+              			#sign.clust <- sign(clusters[head,"r2"])
+                        dia.arrow(c.loc,v.loc$right,labels = round(clusters[head,"r2"],digits),cex=cex,col=colors[((sign.clust)<0) +1],lty=((sign.clust)<0) + 1)
 
               			 } else {
               			 old.head <- head
                			head <- which(rownames(clusters)== clusters[head,2]) 
                			cluster <- clusters[head,]
                			y.shift <- clusters[head,"size1"]
-               			down(clusters,head,x,y-y.shift,old.head=old.head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,...)
+               			down(clusters,head,x,y-y.shift,sign.clust,old.head=old.head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
                			
               					 } 
              }
