@@ -1,4 +1,4 @@
-"factor.scores" <- function(x,f,Phi=NULL,method=c("Thurstone","tenBerge","Anderson","Bartlett","Harman")) {
+"factor.scores" <- function(x,f,Phi=NULL,method=c("Thurstone","tenBerge","Anderson","Bartlett","Harman","components")) {
     if(length(method) > 1) method <- "tenBerge"   #the default
     if(method=="regression") method <- "Thurstone"
      if(!is.matrix(f)) {Phi <- f$Phi
@@ -26,6 +26,7 @@
                w <- f}
       colnames(w) <- colnames(f)
        rownames(w) <- rownames(f)
+
        }, 
       
     "tenBerge" = { #Following Grice equation 8 to estimate scores for oblique solutions
@@ -70,9 +71,14 @@
     colnames(w) <- colnames(f)
     rownames(w) <- rownames(f)
     },
-    "none" = {w <- NULL}
+    "none" = {w <- NULL},
+    
+    "components" = {
+    w <- f }
     )
     
+    
+    
     #now find a few fit statistics
     if(is.null(w)) {results <- list(scores=NULL,weights=NULL)} else {
      R2 <- diag(t(w) %*% f)
@@ -97,6 +103,7 @@
    	  results$R2 <- R2   #this is the multiple R2 of the scores with the factors
      }
      }
+   
      return(results) }
      #how to treat missing data?  see score.item
     
@@ -105,7 +112,7 @@
      
 "matSqrt" <- function(x) {
    e <- eigen(x)
-    e$values[e$values <0] <- .Machine$double.eps
+    e$values[e$values < 0] <- .Machine$double.eps
    sqrt.ev <- sqrt(e$values)   #need to put in a check here for postive semi definite
    result <- e$vectors %*% diag(sqrt.ev) %*% t(e$vectors)
    result}
@@ -115,7 +122,9 @@
    e <- eigen(x)
    if(is.complex(e$values)) {warning("complex eigen values detected by invMatSqrt, results are suspect")
                  result <- x
-                 break} else { e$values[e$values < 0] <- 100 * .Machine$double.eps}
+      } else {
+      
+       e$values[e$values < .Machine$double.eps] <- 100 * .Machine$double.eps
    inv.sqrt.ev <- 1/sqrt(e$values)   #need to put in a check here for postive semi definite
-   result <- e$vectors %*% diag(inv.sqrt.ev) %*% t(e$vectors)
+   result <- e$vectors %*% diag(inv.sqrt.ev) %*% t(e$vectors) }
    result}
