@@ -25,7 +25,8 @@
   
  
  "table2df" <- 
-   function(x,labs = NULL) {
+   function(x,count=NULL, labs = NULL) {
+   if(!is.null(count)) {xm.df <- bigtable2matrix(x,count,labs) } else {
   n <- sum(x)
   nrows <- dim(x)[1]
   ncol <- dim(x)[2]
@@ -46,9 +47,27 @@
        } #end cols
      } #end rows
     if(!is.null(labs)) colnames(xm)<- labs
-    xm.df <- data.frame(xm)
+    xm.df <- data.frame(xm) }
    return(xm.df) 
   }
   
-   
+ "bigtable2matrix" <-
+ function(x,count,labs=NULL) {
+ n <- dim(x)[1]
+ ncol <- dim(x)[2]
+ nrows <- sum(count)
+ xm <- matrix(NA,nrow=nrows,ncol=ncol)
+ k <- 1
+ for (i in 1 :n) {
+   for (j in k:(k+count[i]-1)) {
+   for (values in 1:ncol) {
+    xm[j,values] <- x[i,values] }
+    }
+    k <- k+count[i]
+    }
+ if(!is.null(labs)) {colnames(xm) <- labs}
+  return(xm) 
+  }
+ 
+ 
  
\ No newline at end of file
